@@ -14,7 +14,7 @@ import javax.swing.JPanel;
  *
  * @author Bob Tarling
  */
-public class MainPanel extends javax.swing.JPanel {
+public class MainPanel extends JPanel {
     
     private static MainPanel instance = new MainPanel();
     
@@ -36,3 +36,4 @@ public class MainPanel extends javax.swing.JPanel {
         add(infoPanels);
     }
 }
+
