@@ -6,6 +6,8 @@
 
 package org.tigris.toolbar.actions.uml;
 
+import javax.swing.Icon;
+
 import org.tigris.toolbar.CanvasPanel;
 import org.tigris.toolbar.LogPanel;
 import org.tigris.toolbar.toolbutton.AbstractButtonAction;
@@ -23,13 +25,22 @@ public abstract class UmlAction extends AbstractButtonAction {
     }
 
     public void actionPerformed(java.awt.event.ActionEvent actionEvent) {
+        Icon lockedIcon = null;
+        if (CanvasPanel.getInstance().getModeLocked()) {
+            lockedIcon = CanvasPanel.getInstance().getSelectedIcon();
+        }
         super.actionPerformed(actionEvent);
         boolean doubleClick = isDoubleClick();
+        Icon icon = this.getIcon();
         if (doubleClick) {
             LogPanel.getInstance().add(getName() + " double-clicked");
         } else {
             LogPanel.getInstance().add(getName() + " clicked");
+            if (lockedIcon == this.getIcon()) {
+                icon = null;
+                CanvasPanel.getInstance().deselectOtherTools(null);
+            }
         }
-        CanvasPanel.getInstance().setSelectedIcon(this.getIcon(), doubleClick);
+        CanvasPanel.getInstance().setSelectedIcon(icon, doubleClick);
     }
 }
